import * as equals from "shallowequal";
/**
 * Context.
 */
export class Context {
    constructor() {
        /**
         * Consumer's select props as bitmask.
         */
        this.bitmask = new Map();
    }
    /**
     * calculate bitmask.
     */
    calculateBitmask(nextState) {
        return Array.from(this.bitmask.entries()).reduce((bits, [select, bitState]) => {
            return equals.default(select(nextState), bitState.state)
                ? bits
                : bits | bitState.bit;
        }, 0);
    }
    /**
     * register select function.
     */
    register(select) {
        this.bitmask.set(select, {
            bit: this.bitmask.size + 1
        });
    }
    /**
     * getBitState.
     */
    getBitState(select) {
        return this.bitmask.get(select);
    }
}
//# sourceMappingURL=Context.js.map